@@ -1,18 +1,18 @@
 """Contains checks directly using the Linux operating system concepts."""
 
-from collections.abc import Iterable
 import configparser
-from contextlib import suppress
-from datetime import datetime, UTC
 import os
-from pathlib import Path
 import re
-from re import Pattern
 import socket
 import subprocess
 import time
-from typing import Self
 import warnings
+from collections.abc import Iterable
+from contextlib import suppress
+from datetime import UTC, datetime
+from pathlib import Path
+from re import Pattern
+from typing import Self
 
 import psutil
 
@@ -24,6 +24,11 @@ from . import (
     Wakeup,
 )
 
+try:
+    from psutil._common import snetio
+except ImportError:
+    from psutil._ntuples import snetio
+
 
 class ActiveConnection(Activity):
     """Checks if a client connection exists on specified ports."""
@@ -167,8 +172,8 @@ class NetworkBandwidth(Activity):
     def _check_interface(
         self,
         interface: str,
-        new: psutil._common.snetio,
-        old: psutil._common.snetio,
+        new: snetio,
+        old: snetio,
         new_time: float,
         old_time: float,
     ) -> None:
